<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>RecentFiles</name>
    <message>
        <source>Clear List</source>
        <translation type="obsolete">Effacer la liste</translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+51"/>
        <source>&amp;Clear List</source>
        <translation>&amp;Effacer la liste</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Charger/Enregistrer</translation>
    </message>
    <message>
        <location filename="../RecentFiles.js" line="+35"/>
        <source>Recent Files</source>
        <translation>Fichiers récents</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <source>Open/Save</source>
        <translation type="vanished">Charger/Enregistrer</translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+10"/>
        <source>Open &amp;Recent</source>
        <translation>Ouvrir fichiers &amp;récents</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Recent files history size:</source>
        <translation>Nombre de fichiers récents :</translation>
    </message>
</context>
</TS>
